iops

package
v0.0.0-...-1c24204 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2024 License: Unlicense Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func JoinSafe

func JoinSafe(path ...string) (string, error)

JoinSafe joins the provided path segments and ensures the resulting path is within the base directory. It returns the absolute path if successful.

func MoveFile

func MoveFile(src, dst string) error

MoveFile was implemented because the default os.Rename does not work cross device volumes It will create the destination file structure if it does not exist

Types

This section is empty.

Jump to